@@ -2,4 +2,4 @@
 #define KCRASH_CORE_PATTERN_RAISE 1
 
 #define kde_socklen_t socklen_t
-#define KDE_INSTALL_FULL_LIBEXECDIR "/usr/lib64/libexec"
+#define KDE_INSTALL_FULL_LIBEXECDIR "/usr/libexec"
